
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.5'
version = '1.2.5'
full_version = '1.2.5'
git_revision = '59df905fc3f6af86748f1d494b8430a959f9d4fc'
release = True

if not release:
    version = full_version
    short_version += ".dev"
